#
# spec file for package xfce4-docklike-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.16.0
%define plugin docklike
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        0.4.3
Release:        2.1
Summary:        Docklike Taskbar
License:        GPL-3.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-docklike-plugin/start
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/0.4/%{name}-%{version}.tar.bz2
Patch0:         relax-x11-version.patch
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gettext >= 0.19.8
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo) >= 1.16.0
BuildRequires:  pkgconfig(gdk-wayland-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gdk-x11-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.58.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.58.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gtk-layer-shell-0) >= 0.7.0
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.30.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.16.0
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.16.0
BuildRequires:  pkgconfig(libxfce4windowing-0) >= 4.19.4
BuildRequires:  pkgconfig(libxfce4windowingui-0) >= 4.19.4
BuildRequires:  pkgconfig(x11) >= 1.6.5
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
# uses exo-open
Requires:       exo-tools
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}

%description
Docklike Taskbar behaves similarly to many other desktop environments
and operating systems. Wherein all application windows are grouped
together as an icon and can be pinned to act as a launcher when the
application is not running. Commonly referred to as a dock.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup -p1

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libdocklike.la

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_datadir}/xfce4/panel/plugins/docklike.desktop
%{_libdir}/xfce4/panel/plugins/libdocklike.so

%files lang -f %{name}.lang

%changelog
* Tue Feb  4 2025 Manfred Hollstein <manfred.h@gmx.net>
- License is GPL-3.0-or-later, not GPL-2.0-or-later!
* Sun Dec 29 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.4.3
  * Update copyright year
  * build: Bump dependency versions and fix deprecation warnings
  * I18n: Update po/LINGUAS list
  * Use new xfw_window_activate() signature in libwindowing 4.19.6
  * group: Fix button drawing
  * Fix gtk-layer-shell includes
  * Switch to XfwMonitor
  * Group: Fix null icon size at startup
  * scan-build: Add false positive file
  * build: clang: Fix -Wcast-align
  * Apply .clang-format file
  * clang-format: Use IncludeBlocks::Regroup
  * clang-format: Do not KeepEmptyLinesAtTheStartOfBlocks
  * clang-format: Break after assignment operator
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * clang-format: Insert a newline at end of file if missing
  * Apply updated .clang-format file
  * clang-format: Update according to current code
  * Rename _dialogs.xml to _dialogs.ui for gettext detection
  * I18n: Update po/LINGUAS list
  * build: Get rid of intltool
  * Require gio-unix-2.0 instead of gio-2.0
  * Ignore X11 erros around gdk_pixbuf_get_from_window()
  * Update custom install location in README
  * Adapt onlyDisplayScreen to Xfw
  * Use gtk-layer-shell to position group menu on Wayland
  * Guard X11 code paths
  * Rename Wnck.* to Xfw.*
  * Replace libwnck with libxfce4windowing
  * Wnck: Set EWMH hint so all wnck features work properly (Fixes #51)
  * Translation Updates
- Add relax-x11-version.patch
* Sat Dec 23 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 0.4.2
  * Wnck: Add missing sanity check
  * Settings: Use different colors for active and inactive indicators
  * Use FDO compliant icon name
  * Fix blurry icons/thumbnails when UI scale > 1
  * GroupMenu: Make sure the window is the right size for each popup
  * Group: Stop timeouts in destructor
  * Fix pending source when GroupMenu is destroyed
  * Settings: Bound icon sizes
  * SettingsDialog: Fix deprecated icon names
  * Remove unused project files
  * Remove contrib directory
  * GroupMenu: Re-popup if windows are added/removed when shown
  * Update preview widgets on "showPreviews" setting change
  * Helpers: Always stop timeout before starting a new one
  * Wnck: Always update unactivated window state
  * Group: Do not filter out skip-tasklist windows when activated
  * Group: Do not manually mark window as activated when activating group
  * Group: Update active state when adding windows
  * Group: Remove useless class member states
  * AppInfos: Use also app names for matching
  * Use g_debug for debug logs
  * Replace FALSE with false
  * Replace NULL with nullptr
  * Release data as much as possible on XfcePanelPlugin::free-data signal
  * Wnck: Do not check for active window in init
  * Fix remaining raw pointers not released
  * Manage group button lifetime in Group
  * Revert "Reset pointer when group button is destroyed"
  * Wnck: Use std::shared_ptr to manage memory allocation of GroupWindows
  * Dock: Use std::shared_ptr to manage memory allocation of Groups
  * AppInfos: Use std::shared_ptr to manage memory allocation
  * AppInfos: Wrap raw pointers into std::unique_ptr
  * GroupMenuItem: Fix crash when closing window with preview enabled
  * Revert "group: Fix crash when middle-clicking an item with preview
  enabled"
  * Store pinned apps as ids instead of paths
  * Wnck: Fix memory leaks
  * Theme: Fix memory leaks
  * SettingsDialog: Fix memory leaks
  * Settings: Fix memory leaks
  * Helpers: Fix memory leaks
  * GroupMenuItem: Fix memory leaks
  * Group: Fix memory leaks
  * Dock: Fix memory leaks
  * Fix previous commit
  * Appinfos: Fix some memory leaks
  * Update TODO
  * AppInfos: Honor XDG_DATA_HOME also when editing item
  * AppInfos: Properly honor XDG base dir spec
  * group: Detach menu from button and destroy when hidden (Fixes #20)
  * Fix cplusplus.StringChecker warning from scan-build 16.0.6
  * Use glib functions for memory allocation
  * build: Fix -Wunused-function warnings
  * build: Fix -Wdangling-else warnings
  * build: Fix -Wsequence-point warnings
  * build: Fix -Wsign-compare warnings
  * build: Fix -Wmaybe-uninitialized warnings
  * build: Fix -Wshadow warnings
  * build: Fix -Wmissing-declarations warnings
  * group-menu-item: Refresh preview less often
  * group: Fix missing dnd icon
  * group: Fix crash when middle-clicking an item with preview enabled
  * Reset pointer when group button is destroyed
  * helpers: Reset source id when removed
  * app-infos: Get translated app name (Fixes #67)
  * Fix help button icon to be same as other plugins
  * Added middle mouse button do nothing option
  * Added closedir call to prevent too many open files error (Fixes #54)
  * Fix previous commit
  * Fix copyright info
  * Translation Updates
* Wed Mar 22 2023 Manfred Hollstein <manfred.h@gmx.net>
- Initial package version 0.4.1
  * build: Use same automake init as other projects and bump autoconf
  * Update copyright year and fix bug report address
  * build: Use XDT_FEATURE_DEBUG
  * basename() called but <libgen.h> not included
  * Add option to change behavior of middle mouse button (Closes #32)
  * build: Keep /usr/local as default prefix
  * build: Fix autotools warnings
  * build: Fix intltool lock file problem during make distcheck
  * build: Bump GLib minimum required to 2.58
  * Anchor group menu to center of app icon
  * Add option to change inactive indicator style
  * List window previews horizontally if panel is horizontal
  * Add option to get the indicator color automatically from the Gtk
    theme foreground color
  * Startup notification support Closes #13 Additionally, correctly
    release memory after launching.
  * Reorder AppInfos.cpp for clarity
  * Skip loadDesktopEntry() for files not ending in .desktop
  * Pass std::string by const reference to avoid unnecessary copy
  * Speed up ftw() by increasing handle limit
  * Added Ciliora and Circles indicator styles
  * Fix reordering (ctrl+dragging) icons to the right
  * Fix size_t being truncated into uint and comparing unequal to npos
  * Fix .desktop file StartupWMClass values being ignored
  * Update TODO
  * Fix warnings/crashes from timeouts In many cases the timeout's stop
    method was being called more than once raising GLib warnings.
  * Don't clear this list
  * Delete unused declarations
  * Improve PANEL_DEBUG macro
  * Improve debugging messages
  * Drop the inotify dependency GLib provides a GAppInfoMonitor object
    that allows us to detect desktop file changes.
  * Use the default theme hover effect The previous effect can still be
    achieved with CSS:
  * Update the README Better debugging instructions and long desctiption.
  * Cleanup: remove uneccessary casts to GtkWidget*
  * Remove highlight on active group Related #14 It can be restored by
    using css or a future option.
  * Add a "window_count" class to labels Related #9
  * Translation Updates
